==> MoinLight-0.1.tar.bz2: MoinLight-0.1/moinformat/utils/links.py <==
#!/usr/bin/env python

"""
Link target parsing.

Copyright (C) 2018, 2019 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from urlparse import urlparse

class LinkTarget:

    "A link target abstraction."

    def __init__(self, type, text, identifier=None):

        "Initialise the link with the given 'type', 'text' and 'identifier'."

        self.type = type
        self.text = text
        self.identifier = identifier

    def __repr__(self):
        return "LinkTarget(%r, %r, %r)" % (self.type, self.text, self.identifier)

    def __str__(self):
        return self.text

    __unicode__ = __str__

    def get_identifier(self):
        if self.identifier is not None:
            return self.identifier
        else:
            return self.text

    def get_text(self):
        return self.text

    def get_type(self):
        return self.type

# Parsing and recognition functions.

def is_url(target):

    "Return whether the 'target' references a URL."

    scheme, host, path, params, query, fragment = urlparse(target)
    return scheme and target or None

def parse_link_target(target, metadata=None):

    """
    Parse a link 'target', returning a link target object. Use any 'metadata'
    to identify certain link types.
    """

    # Fragments.

    if target.startswith("#"):
        return LinkTarget("fragment", target, target.lstrip("#"))

    # Sub-pages.

    if target.startswith("/"):
        return LinkTarget("sub-page", target, target.lstrip("/").rstrip("/"))

    # Sibling (of ancestor) pages.

    if target.startswith("../"):
        return LinkTarget("sibling-page", target, target.rstrip("/"))

    # Attachment or interwiki link.

    result = parse_qualified_link_target(target, metadata)
    if result:
        return result 

    # Plain URL.

    if is_url(target):
        return LinkTarget("url", target)

    # Top-level pages.

    return LinkTarget("page", target)

def parse_qualified_link_target(target, metadata=None):

    """
    Parse a possible qualified link 'target', returning a link target object or
    None if the target is not suitable. Use any 'metadata' to identify certain
    link types.
    """

    t = target.split(":", 1)

    if len(t) != 2:
        return None

    prefix, identifier = t

    mapping = metadata and metadata.get("mapping")

    if prefix == "attachment" or mapping and mapping.get(prefix):
        return LinkTarget(prefix, target, identifier)

    return None

# vim: tabstop=4 expandtab shiftwidth=4

==> MoinLight-0.2.1.tar.bz2: MoinLight-0.2.1/moinformat/utils/links.py <==
#!/usr/bin/env python

"""
Link target parsing.

Copyright (C) 2018, 2019, 2022 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from urlparse import urlparse

class LinkTarget:

    "A link target abstraction."

    def __init__(self, type, text, identifier=None, pagename=None):

        """
        Initialise the link with the given 'type', 'text', and optional
        'identifier' and 'pagename'.
        """

        self.type = type
        self.text = text
        self.identifier = identifier
        self.pagename = pagename

    def __repr__(self):
        return "LinkTarget(%r, %r, %r, %r)" % (self.type, self.text,
                                               self.identifier, self.pagename)

    def __str__(self):
        return self.text

    __unicode__ = __str__

    def get_identifier(self):
        if self.identifier is not None:
            return self.identifier
        else:
            return self.text

    def get_pagename(self):
        return self.pagename

    def get_text(self):
        return self.text

    def get_type(self):
        return self.type

# Parsing and recognition functions.

def is_url(target):

    "Return whether the 'target' references a URL."

    scheme, host, path, params, query, fragment = urlparse(target)
    return scheme and target or None

def parse_link_target(target, metadata=None):

    """
    Parse a link 'target', returning a link target object. Use any 'metadata'
    to identify certain link types.
    """

    # Fragments.

    if target.startswith("#"):
        return LinkTarget("fragment", target, target.lstrip("#"))

    # Sub-pages.

    if target.startswith("/"):
        return LinkTarget("sub-page", target, target.lstrip("/").rstrip("/"))

    # Sibling (of ancestor) pages.

    if target.startswith("../"):
        return LinkTarget("sibling-page", target, target.rstrip("/"))

    # Attachment or interwiki link.

    result = parse_qualified_link_target(target, metadata)
    if result:
        return result 

    # Plain URL.

    if is_url(target):
        return LinkTarget("url", target)

    # Top-level pages.

    return LinkTarget("page", target)

def parse_qualified_link_target(target, metadata=None):

    """
    Parse a possible qualified link 'target', returning a link target object or
    None if the target is not suitable. Use any 'metadata' to identify certain
    link types.
    """

    t = target.split(":", 1)

    if len(t) != 2:
        return None

    prefix, identifier = t

    mapping = metadata and metadata.get("mapping")

    if prefix == "attachment" or mapping and mapping.get(prefix):
        return LinkTarget(prefix, target, identifier)

    return None

# vim: tabstop=4 expandtab shiftwidth=4
